==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/kn.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "ದಾಖಲೆಗಳು",
"Can't create document" => "ದಾಖಲೆಯನ್ನು ಸೃಷ್ಟಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ",
"You don't have permission to rename this document" => "ಈ ದಾಖಲೆಯ ಮರುನಾಮಕರಣ ಮಾಡುವುದಕ್ಕೆ ಅನುಮತಿಯಿಲ್ಲ",
"Directory saved successfully." => "ಕೋಶದಲ್ಲಿ ಯಶಸ್ವಿಯಾಗಿ ಉಳಿಸಲಾಗಿದೆ.",
"An error occurred while changing directory." => "ಕೋಶವನ್ನು ಬದಲಾವಣೆ ಮಾಡುವಾಗ ದೋಷ ಸಂಭವಿಸಿದೆ.",
"Saved" => "﻿ಉಳಿಸಿದ",
"Saving..." => "﻿ಉಳಿಸಲಾಗುತ್ತಿದೆ ...",
"Failed to load documents." => "ದಾಖಲೆಗಳನ್ನು ಹೊಂದಿಸಲು ವಿಫಲವಾಗಿದೆ.",
"No documents were found. Upload or create a document to get started!" => "ಇಲ್ಲಿ ಯಾವುದೇ ದಾಖಲೆಗಳನ್ನು ಕಂಡುಬಂದಿಲ್ಲ. ದಾಖಲೆಯನ್ನು ಸೃಷ್ಟಿಸಲು ಪ್ರಾರಂಭಿಸಿ ಅಥವ ಪೇರಿಸಿ !",
"No connection to server. Trying to reconnect." => "ಪರಿಚಾರಕ-ಗಣಕದೊಂದಿಗೆ ಸಂಪರ್ಕವಿಲ್ಲ. ಮತ್ತೆ ಪ್ರಯತ್ನಿಸಲಾಗುತ್ತಿದೆ.",
"Save" => "﻿ಉಳಿಸಿ",
"Loading documents..." => "ದಾಖಲೆಗಳನ್ನು ಹೊಂದಿಸಲಾಗುತ್ತಿದೆ...",
"'.' is an invalid file name." => "'.' ಅಮಾನ್ಯ ಕಡತದ ಹೆಸರು.",
"File name cannot be empty." => "ಕಡತ ಹೆಸರು ಖಾಲಿ ಇರುವಂತಿಲ್ಲ.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "﻿ಅಮಾನ್ಯವಾದ ಹೆಸರು, '\\', '/', '<', '>', ':', '\"', '|', '?' ಮತ್ತು '*'  ಅನುಮತಿ ಇಲ್ಲ.",
"Align Left" => "ಎಡಕ್ಕೆ ಹೊಂದಿಸು",
"Alignment" => "ಸಾಲುಗೂಡಿಕೆ",
"Align Right" => "ಬಲಕ್ಕೆ ಹೊಂದಿಸು",
"Annotate" => "ಉಲ್ಲೇಖ",
"Background" => "ಹಿನ್ನೆಲೆ",
"Bold" => "ದಪ್ಪ",
"Bottom" => "ಕೆಳಗೆ",
"Cancel" => "﻿ರದ್ದು",
"Center" => "ಕೇಂದ್ರ",
"Clone" => "ನಕಲು",
"Clone this Style" => "ಈ ಶೈಲಿಯನ್ನು ನಕಲ ಮಾಡು",
"Close" => "ಮುಚ್ಚು",
"Color" => "ಬಣ್ಣ",
"Create" => "ಸೃಷ್ಟಿಸಿ",
"Decrease Indent" => "ಸಂಕಸ್ಥಾನ ಕಡಿಮೆಮಾಡು",
"Default Style" => "ಪೂರ್ವನಿಯೋಜಿತ ಶೈಲಿ",
"Delete" => "﻿ಅಳಿಸಿ",
"Family" => "ಕುಟುಂಬ",
"Font" => "ಅಕ್ಷರಶೈಲಿ",
"Font Effects" => "ಅಕ್ಷರಶೈಲಿಯ ಪ್ರಭಾವಗಳು",
"Format" => "ಸ್ವರೂಪ",
"Increase Indent" => "ಸಂಕಸ್ಥಾನ ಹೆಚ್ಚಿಸು",
"Insert Image" => "ಚಿತ್ರವನ್ನು ಸೇರಿಸಿ",
"Invite Members" => "ಸದಸ್ಯರು ಆಹ್ವಾನಿಸಿ",
"Italic" => "ಓರೆ",
"Justified" => "ಸರಿಹೊಂದಿಸಲಾಗಿದೆ",
"Justify" => "ಸರಿಹೊಂದಿಸು",
"Left" => "ಎಡ",
"Loading" => "ಹೊಂದಿಸಲಾಗುತ್ತಿದೆ",
"Members" => "ಸದಸ್ಯರು",
"New Name:" => "ಹೊಸ ಹೆಸರು:",
"OK" => "ಸರಿ",
"Open" => "ತೆರೆ",
"Options" => "ಆಯ್ಕೆಗಳು",
"Paragraph..." => "ವಾಕ್ಯವೃಂದ...",
"Paragraph Styles" => "ವಾಕ್ಯವೃಂದದ ಶೈಲಿಗಳು",
"Redo" => "ಹಿಂದಿರುಗಿಸು",
"Right" => "ಬಲ",
"Size" => "﻿ ಗಾತ್ರ",
"Spacing" => "ಅಂತರ",
"Strikethrough" => "ಅಡ್ದಗೆರೆ",
"Style" => "ಶೈಲಿ",
"Text" => "ವಿಷಯ",
"Top" => "ಮೇಲಿನ",
"Underline" => "ಅಡಿಗೆರೆ",
"Undo" => "ರದ್ದು",
"Unknown Author" => "ಅಪರಿಚಿತ ಲೇಖಕ",
"Edit" => "ಸಂಪಾದಿಸು",
"Share" => "﻿ಹಂಚಿಕೊಳ್ಳಿ",
"guest" => "ಅತಿಥಿ",
"Local" => "ಸ್ಥಳೀಯ",
"External" => "ಹೊರಗಿನ",
"Disabled" => "ನಿಷ್ಕ್ರಿಯಗೊಳಿಸಲಾಗಿದೆ",
"No MS Word support" => "MS Word ನ ಇಲ್ಲ ಬೆಂಬಲ",
"scheme://domain.tld[:port]" => "ಯೋಜನೆ://domain.tld[: ಸಂಪರ್ಕಸ್ಥಾನ]",
"Server URL" => "ಪರಿಚಾರಕ-ಗಣಕದ  ವಿಳಾಸ **ಏಕರೂಪದ ಸಂಪನ್ಮೂಲ ಗುರುತುಕಾರಕ",
"Apply and test" => "ಅರ್ಜಿ ಮತ್ತು ಪರೀಕ್ಷಾ",
"New document" => "ಹೊಸ ದಾಖಲೆ",
"Upload (max. %s)" => "ಪೇರಿಸು (ಗರಿಷ್ಠ %s)",
"Upload" => "ಪೇರಿಸು",
"Save new documents to" => "ಹೊಸ ಕಡತಗಳನ್ನು ಇಲ್ಲಿ ಉಳಿಸಿ",
"Wrong password. Please retry." => "ತಪ್ಪಾದ ಗುಪ್ತಪದ. ಮರುಪ್ರಯತ್ನಿಸಿ.",
"Password" => "ಗುಪ್ತ ಪದ",
"Guest %s" => "ಅತಿಥಿ %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "ಈ ಅಂತರ್ಜಾಲ ಕೊಂಡಿಯ ಕಾಲಾವಧಿ ಮುಗಿದಿದೆ ಅಥವಾ ಅಸ್ತಿತ್ವದಲಿಲ್ಲ. ವಿವರಗಳಿಗಾಗಿ ನೀವು ಅದನ್ನು ಹಂಚಿಕೊಂಡ ವ್ಯಕ್ತಿಯನ್ನು ಸಂಪರ್ಕಿಸಿ.",
"Advanced feature-set" => "ಸುಧಾರಿತ ವೈಶಿಷ್ಟ್ಯಗಳು"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";

==> owncloud-app-documents-1%3A9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/kn.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "ದಾಖಲೆಗಳು",
"Can't create document" => "ದಾಖಲೆಯನ್ನು ಸೃಷ್ಟಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ",
"You don't have permission to rename this document" => "ಈ ದಾಖಲೆಯ ಮರುನಾಮಕರಣ ಮಾಡುವುದಕ್ಕೆ ಅನುಮತಿಯಿಲ್ಲ",
"Directory saved successfully." => "ಕೋಶದಲ್ಲಿ ಯಶಸ್ವಿಯಾಗಿ ಉಳಿಸಲಾಗಿದೆ.",
"An error occurred while changing directory." => "ಕೋಶವನ್ನು ಬದಲಾವಣೆ ಮಾಡುವಾಗ ದೋಷ ಸಂಭವಿಸಿದೆ.",
"Saved" => "﻿ಉಳಿಸಿದ",
"Saving..." => "﻿ಉಳಿಸಲಾಗುತ್ತಿದೆ ...",
"Failed to load documents." => "ದಾಖಲೆಗಳನ್ನು ಹೊಂದಿಸಲು ವಿಫಲವಾಗಿದೆ.",
"No documents were found. Upload or create a document to get started!" => "ಇಲ್ಲಿ ಯಾವುದೇ ದಾಖಲೆಗಳನ್ನು ಕಂಡುಬಂದಿಲ್ಲ. ದಾಖಲೆಯನ್ನು ಸೃಷ್ಟಿಸಲು ಪ್ರಾರಂಭಿಸಿ ಅಥವ ಪೇರಿಸಿ !",
"No connection to server. Trying to reconnect." => "ಪರಿಚಾರಕ-ಗಣಕದೊಂದಿಗೆ ಸಂಪರ್ಕವಿಲ್ಲ. ಮತ್ತೆ ಪ್ರಯತ್ನಿಸಲಾಗುತ್ತಿದೆ.",
"Save" => "﻿ಉಳಿಸಿ",
"Loading documents..." => "ದಾಖಲೆಗಳನ್ನು ಹೊಂದಿಸಲಾಗುತ್ತಿದೆ...",
"'.' is an invalid file name." => "'.' ಅಮಾನ್ಯ ಕಡತದ ಹೆಸರು.",
"File name cannot be empty." => "ಕಡತ ಹೆಸರು ಖಾಲಿ ಇರುವಂತಿಲ್ಲ.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "﻿ಅಮಾನ್ಯವಾದ ಹೆಸರು, '\\', '/', '<', '>', ':', '\"', '|', '?' ಮತ್ತು '*'  ಅನುಮತಿ ಇಲ್ಲ.",
"Align Left" => "ಎಡಕ್ಕೆ ಹೊಂದಿಸು",
"Alignment" => "ಸಾಲುಗೂಡಿಕೆ",
"Align Right" => "ಬಲಕ್ಕೆ ಹೊಂದಿಸು",
"Annotate" => "ಉಲ್ಲೇಖ",
"Background" => "ಹಿನ್ನೆಲೆ",
"Bold" => "ದಪ್ಪ",
"Bottom" => "ಕೆಳಗೆ",
"Cancel" => "﻿ರದ್ದು",
"Center" => "ಕೇಂದ್ರ",
"Clone" => "ನಕಲು",
"Clone this Style" => "ಈ ಶೈಲಿಯನ್ನು ನಕಲ ಮಾಡು",
"Close" => "ಮುಚ್ಚು",
"Color" => "ಬಣ್ಣ",
"Create" => "ಸೃಷ್ಟಿಸಿ",
"Decrease Indent" => "ಸಂಕಸ್ಥಾನ ಕಡಿಮೆಮಾಡು",
"Default Style" => "ಪೂರ್ವನಿಯೋಜಿತ ಶೈಲಿ",
"Delete" => "﻿ಅಳಿಸಿ",
"Family" => "ಕುಟುಂಬ",
"Font" => "ಅಕ್ಷರಶೈಲಿ",
"Font Effects" => "ಅಕ್ಷರಶೈಲಿಯ ಪ್ರಭಾವಗಳು",
"Format" => "ಸ್ವರೂಪ",
"Increase Indent" => "ಸಂಕಸ್ಥಾನ ಹೆಚ್ಚಿಸು",
"Insert Image" => "ಚಿತ್ರವನ್ನು ಸೇರಿಸಿ",
"Invite Members" => "ಸದಸ್ಯರು ಆಹ್ವಾನಿಸಿ",
"Italic" => "ಓರೆ",
"Justified" => "ಸರಿಹೊಂದಿಸಲಾಗಿದೆ",
"Justify" => "ಸರಿಹೊಂದಿಸು",
"Left" => "ಎಡ",
"Loading" => "ಹೊಂದಿಸಲಾಗುತ್ತಿದೆ",
"Members" => "ಸದಸ್ಯರು",
"New Name:" => "ಹೊಸ ಹೆಸರು:",
"OK" => "ಸರಿ",
"Open" => "ತೆರೆ",
"Options" => "ಆಯ್ಕೆಗಳು",
"Paragraph..." => "ವಾಕ್ಯವೃಂದ...",
"Paragraph Styles" => "ವಾಕ್ಯವೃಂದದ ಶೈಲಿಗಳು",
"Redo" => "ಹಿಂದಿರುಗಿಸು",
"Right" => "ಬಲ",
"Size" => "﻿ ಗಾತ್ರ",
"Spacing" => "ಅಂತರ",
"Strikethrough" => "ಅಡ್ದಗೆರೆ",
"Style" => "ಶೈಲಿ",
"Text" => "ವಿಷಯ",
"Top" => "ಮೇಲಿನ",
"Underline" => "ಅಡಿಗೆರೆ",
"Undo" => "ರದ್ದು",
"Unknown Author" => "ಅಪರಿಚಿತ ಲೇಖಕ",
"Shared" => "﻿ಹಂಚಿಕೆಯ",
"Error" => "﻿ತಪ್ಪಾಗಿದೆ",
"Error while sharing" => "ಹಂಚುವಾಗ ಏನೊ ಲೋಪವಾಗಿದೆ",
"Error while unsharing" => " ಹಂಚಿಕೆಯನ್ನು ಹಿಂದೆರುಗಿಸು ಸಂದರ್ಭದಲ್ಲಿ ಲೋಪವಾಗಿದೆ",
"Error while changing permissions" => "ಅನುಮತಿಗಳನ್ನು ಬದಲಾವಣೆ ಮಾಡುವಾಗ ದೋಷವಾಗಿದೆ",
"Shared with you and the group {group} by {owner}" => "ನಿಮಗೆ ಮತ್ತು {group} ಗುಂಪಿನೂಂದಿಗೆ {owner} ಹಂಚಿಕೊಂಡಿದ್ದಾರೆ",
"Shared with you by {owner}" => "﻿ನಿಮ್ಮೊಂದಿಗೆ {owner} ಹಂಚಿಕೊಂಡಿದ್ದಾರೆ",
"Share" => "﻿ಹಂಚಿಕೊಳ್ಳಿ",
"Share link" => "ಸಂಪರ್ಕ ಕೊಂಡಿಯನ್ನು  ﻿ಹಂಚಿಕೊಳ್ಳಬಹುದು",
"The public link will expire no later than {days} days after it is created" => "﻿ರಚನೆಯಾದ {days} ದಿನಗಳ ನಂತರ ಈ ಸಾರ್ವಜನಿಕ ಸಂಪರ್ಕ ಕೊಂಡಿ ಅಂತ್ಯಗೊಳ್ಳಲಿದೆ",
"Link" => "ಸಂಪರ್ಕ ಕೊಂಡಿ",
"Password protect" => "﻿ಗುಪ್ತಪದ ರಕ್ಷಿಸಿಕೂಳ್ಲಿ",
"Password" => "ಗುಪ್ತ ಪದ",
"Choose a password for the public link" => "ಸಾರ್ವಜನಿಕ ಸಂಪರ್ಕ ಕೊಂಡಿಗೆ ಗುಪ್ತಪದ ಆಯ್ಕೆಮಾಡಿ",
"Allow editing" => "﻿ಸಂಪಾದನೆಗೆ ಅವಕಾಶ ಮಾಡಿಕೊಡಿ",
"Email link to person" => "ಬಳಕೆದಾರನ ಇ-ಅಂಚೆಯ ಸಂಪರ್ಕಕೊಂಡಿ",
"Send" => "﻿ಕಳುಹಿಸಿ",
"Set expiration date" => "ಮುಕ್ತಾಯ ದಿನಾಂಕವನ್ನು ನಿರ್ದರಿಸಿ",
"Expiration" => "﻿ಮುಕ್ತಾಯ",
"Expiration date" => "ಮುಕ್ತಾಯ ದಿನಾಂಕ",
"Adding user..." => "﻿ಬಳಕೆದಾರನನ್ನು ಸೇರಿಸಲಾಗುತ್ತಿದೆ ...",
"group" => "﻿ಗುಂಪು",
"remote" => "ಆಚೆಯ",
"Resharing is not allowed" => "﻿ಮರುಹಂಚಿಕೆ ಅನುಮತಿಸಲಾಗುವುದಿಲ್ಲ",
"Shared in {item} with {user}" => "{user} ﻿ಜೊತೆ {item} ಹಂಚಿಕೊಳ್ಳಲಾಗಿದೆ",
"Unshare" => "ಹಂಚಿಕೆಯನ್ನು ಹಿಂತೆಗೆ",
"notify by email" => "﻿ಇ-ಅಂಚೆ ಮೂಲಕ ತಿಳಿಸಲು",
"can share" => "﻿ಹಂಚಿಕೊಳ್ಳಬಹುದು",
"can edit" => "﻿ಸಂಪಾದಿಸಬಹುದು",
"access control" => "﻿ಪ್ರವೇಶ ನಿಯಂತ್ರಣ",
"create" => "ಸೃಷ್ಟಿಸು",
"change" => "﻿ಬದಲಾವಣೆ",
"delete" => "﻿ಅಳಿಸಿ",
"Password protected" => "ಗುಪ್ತಪದದಿಂದ ರಕ್ಷಿಸಲಾಗಿದೆ",
"Error unsetting expiration date" => "ಮುಕ್ತಾಯ ದಿನಾಂಕವನ್ನು ಹಿಂಪಡೆಯುವಲಿ್ಲ ದೋಷ",
"Error setting expiration date" => "ಮುಕ್ತಾಯ ದಿನಾಂಕವನ್ನು ನಿರ್ದರಿಸುವಲ್ಲಿ ದೋಷ",
"Sending ..." => "﻿ಕಳುಹಿಸಲಾಗುತ್ತಿದೆ ...",
"Email sent" => "ಇ-ಅಂಚೆ ಕಳುಹಿಸಲಾಗಿದೆ",
"Warning" => "﻿ಎಚ್ಚರಿಕೆ",
"Edit" => "ಸಂಪಾದಿಸು",
"guest" => "ಅತಿಥಿ",
"Local" => "ಸ್ಥಳೀಯ",
"External" => "ಹೊರಗಿನ",
"Disabled" => "ನಿಷ್ಕ್ರಿಯಗೊಳಿಸಲಾಗಿದೆ",
"No MS Word support" => "MS Word ನ ಇಲ್ಲ ಬೆಂಬಲ",
"scheme://domain.tld[:port]" => "ಯೋಜನೆ://domain.tld[: ಸಂಪರ್ಕಸ್ಥಾನ]",
"Server URL" => "ಪರಿಚಾರಕ-ಗಣಕದ  ವಿಳಾಸ **ಏಕರೂಪದ ಸಂಪನ್ಮೂಲ ಗುರುತುಕಾರಕ",
"Apply and test" => "ಅರ್ಜಿ ಮತ್ತು ಪರೀಕ್ಷಾ",
"New document" => "ಹೊಸ ದಾಖಲೆ",
"Upload (max. %s)" => "ಪೇರಿಸು (ಗರಿಷ್ಠ %s)",
"Upload" => "ಪೇರಿಸು",
"Save new documents to" => "ಹೊಸ ಕಡತಗಳನ್ನು ಇಲ್ಲಿ ಉಳಿಸಿ",
"Wrong password. Please retry." => "ತಪ್ಪಾದ ಗುಪ್ತಪದ. ಮರುಪ್ರಯತ್ನಿಸಿ.",
"Guest %s" => "ಅತಿಥಿ %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "ಈ ಅಂತರ್ಜಾಲ ಕೊಂಡಿಯ ಕಾಲಾವಧಿ ಮುಗಿದಿದೆ ಅಥವಾ ಅಸ್ತಿತ್ವದಲಿಲ್ಲ. ವಿವರಗಳಿಗಾಗಿ ನೀವು ಅದನ್ನು ಹಂಚಿಕೊಂಡ ವ್ಯಕ್ತಿಯನ್ನು ಸಂಪರ್ಕಿಸಿ.",
"Advanced feature-set" => "ಸುಧಾರಿತ ವೈಶಿಷ್ಟ್ಯಗಳು"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
